@@ -1,5 +1,6 @@
 from .download import download_file
 from .notification import send_notification
+from .stats_utils import get_var_stats
 from .var_utils import DEFAULT_PAGE_SIZE, format_var, format_vars
 from .version import __version__, __version_info__
 
@@ -11,4 +12,5 @@ __all__ = [
     "download_file",
     "__version_info__",
     "__version__",
+    "get_var_stats",
 ]
