@@ -77,8 +77,8 @@ def get_list_var(
     no_preview=False,
     page_size=DEFAULT_PAGE_SIZE,
     page=0,
-    sort_by=[],
-    ascending=[True],
+    sort_by=None,
+    ascending=None,
     filters=None,
 ):
     """
@@ -114,7 +114,8 @@ def get_list_var(
         end = start + page_size if has_next_page else len(obj_filtered)
 
         if (
-            len(sort_by) > 0
+            isinstance(sort_by, list)
+            and len(sort_by) > 0
             and isinstance(sort_by[0], str)
             and sort_by[0].lower() == "value"
         ):
@@ -202,7 +203,11 @@ def get_dict_var(
         )
         end = start + page_size if has_next_page else len(obj_filtered)
 
-        if len(sort_by) > 0 and isinstance(sort_by[0], str):
+        if (
+            isinstance(sort_by, list)
+            and len(sort_by) > 0
+            and isinstance(sort_by[0], str)
+        ):
             obj_sorted = []
 
             if (
@@ -258,8 +263,8 @@ def get_numpy_2d_var(
     no_preview=False,
     page_size=DEFAULT_PAGE_SIZE,
     page=0,
-    sort_by=[],
-    ascending=[True],
+    sort_by=None,
+    ascending=None,
     filters=None,
 ):
     """
@@ -329,7 +334,7 @@ def get_numpy_2d_var(
             ):
                 asc_value = ascending[0]
             else:
-                asc_value = False
+                asc_value = True
 
             # Enter the columns in reverse order, because the
             # last index will be the primary sort index (which is backwards from pandas)
@@ -370,8 +375,8 @@ def get_numpy_1d_var(
     no_preview=False,
     page_size=DEFAULT_PAGE_SIZE,
     page=0,
-    sort_by=[],
-    ascending=[True],
+    sort_by=None,
+    ascending=None,
     filters=None,
 ):
     summary = f"Length: {obj.shape[0]} Memory: {human_bytes(obj.nbytes)}"
@@ -440,7 +445,7 @@ def get_numpy_1d_var(
             elif isinstance(ascending, bool):
                 asc_value = ascending
             else:
-                asc_value = False
+                asc_value = True
 
             if sort_by_param in ["value", "values", name]:
                 if obj_filtered.dtype == "O":
@@ -481,8 +486,8 @@ def get_pandas_dataframe_var(
     no_preview=False,
     page_size=DEFAULT_PAGE_SIZE,
     page=0,
-    sort_by=[],
-    ascending=[True],
+    sort_by=None,
+    ascending=None,
     filters=None,
 ):
     """
@@ -582,8 +587,8 @@ def get_pandas_series_var(
     no_preview=False,
     page_size=DEFAULT_PAGE_SIZE,
     page=0,
-    sort_by=[],
-    ascending=[True],
+    sort_by=None,
+    ascending=None,
     filters=None,
 ):
     """
@@ -692,8 +697,8 @@ def get_var_details(
     no_preview=False,
     page_size=DEFAULT_PAGE_SIZE,
     page=0,
-    sort_by=[],
-    ascending=[True],
+    sort_by=None,
+    ascending=None,
     filters=None,
 ):
     """
@@ -879,8 +884,8 @@ def format_var(
     name,
     page_size=DEFAULT_PAGE_SIZE,
     page=0,
-    sort_by=[],
-    ascending=[True],
+    sort_by=None,
+    ascending=None,
     filters=None,
     **kwargs,
 ):
